@@ -35,6 +35,7 @@ class S3Uploader(object):
 
     def __init__(self, s3_client,
                  bucket_name,
+                 region,
                  prefix=None,
                  kms_key_id=None,
                  force_upload=False,
@@ -44,6 +45,7 @@ class S3Uploader(object):
         self.kms_key_id = kms_key_id or None
         self.force_upload = force_upload
         self.s3 = s3_client
+        self.region = region
 
         self.transfer_manager = transfer_manager
         if not transfer_manager:
@@ -160,6 +162,21 @@ class S3Uploader(object):
 
             return md5.hexdigest()
 
+    def to_path_style_s3_url(self, key, version=None):
+        """
+            This link describes the format of Path Style URLs
+            http://docs.aws.amazon.com/AmazonS3/latest/dev/UsingBucket.html#access-bucket-intro
+        """
+        base = "https://s3.amazonaws.com"
+        if self.region and self.region != "us-east-1":
+            base = "https://s3-{0}.amazonaws.com".format(self.region)
+
+        result = "{0}/{1}/{2}".format(base, self.bucket_name, key)
+        if version:
+            result = "{0}?versionId={1}".format(result, version)
+
+        return result
+
 
 class ProgressPercentage(BaseSubscriber):
     # This class was copied directly from S3Transfer docs
